`brierScore` <-
function(fit, ensembleData, thresholds, dates = NULL, ...) 
UseMethod("brierScore")

